.\" toc-example-2.ms: vim: filetype=groff
.\"
.\" A simple example of linked TOC in PDF; in this case,
.\" each TOC entry is mirrored in the document outline.
.\"
.\" Format with:
.\"   touch toc.import
.\"   pdfroff -U -mspdf --no-toc-relocation toc-example-2.ms \
.\"      > toc-example-2.pdf
.
.pdfview /PageMode /UseOutlines
.
.\" ========================================
.\"  Markup for front matter would go here.
.\" ========================================
.
.\" Set margins for the TOC page.
.
.nr PO  3.0c
.nr LL 15.0c
.
.\" Emit the TOC page heading...
.\" In this instance, this also initialises ms state.
.
.SH 1
.ce 1
Table of Contents
.sp 2c
.
.\" Tabstop settings must come *after* ms initialisation;
.\" the first is where the TOC entry leader ends; the second
.\" provides right justification for the page numbers.
.
.ta \n[LL]u-1.0c \n[LL]uR
.
.de XH
.\" A macro for specifying headings with linked TOC entries...
.\"
.\" Inputs:
.\"   $1 = S for SH headings; N for NH
.\"   $2 = heading level; (e.g. .NH 2, for $2 = 2)
.\"   $3 = initial text of heading; (propagates to TOC)
.\"
.\" Returns:
.\"   \*[PDFBOOKMARK.NAME] = PDF reference label @ heading location
.\"
.   \\$1H \\$2
.   pdfhref O \\$2 \\$3
.   write toc .pdfhref L -D \\*[PDFBOOKMARK.NAME] -- "\\$3\0\0\\\\a\\\\t\\n%"
.   nop \\$3
..
.
.\" Merge dynamically generated markup, to lay out the TOC
.
.so toc.import
.
.\" Reinitialise the TOC markup file, and reference counter,
.\" to begin capture of freshly updated TOC layout markup.
.
.open toc toc.import
.nr toc.reference.count 0 1
.
.\" Reset page margins and tabstops for body of document,
.\" and advance to new page, to begin formatting it.
.
.nr PO  2.0c
.nr LL 17.0c
.ta
.bp
.
.\" ===========================
.\"  Document Body Begins Here
.\" ===========================
.
.XH S 1 Introduction
.LP
This is a trivial example of a heading,
with a live table of contents reference.
This example also associates a document outline entry
with the same link destination as each table of contents entry.
.
.LP
Notice that,
in this example,
the TOC reference counter was not used;
it remains at its initial value of \n[toc.reference.count].
.
.\" May not be strictly necessary...
.\" but for completeness, we close the TOC markup capture file.
.
.close toc
.
.\" toc-example-2.ms: end of file
